==> spongeapi-8.0.0-20210211.013413-350-sources.jar: org/spongepowered/api/profile/GameProfileManager.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.profile;

/**
 * Manages {@link GameProfile} creation and data population.
 *
 * <p>The manager may cache the data of a request for faster lookups. Note that
 * the cached data may not always be up to date.</p>
 */
public interface GameProfileManager extends GameProfileProvider {

    /**
     * Gets the {@link GameProfileCache} of this provider which will be
     * used to cache game profiles.
     *
     * <p>In vanilla, properties do not persist between restarts and profiles
     * will expire after a month.</p>
     *
     * @return The cache
     */
    GameProfileCache getCache();

    /**
     * Gets a {@link GameProfileProvider} which bypasses the
     * {@link GameProfileCache}.
     *
     * @return The uncached game profile provider
     */
    GameProfileProvider uncached();
}

==> spongeapi-8.0.0-20210324.005901-379-sources.jar: org/spongepowered/api/profile/GameProfileManager.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.profile;

/**
 * Manages {@link GameProfile} creation and data population.
 *
 * <p>The manager may cache the data of a request for faster lookups. Note that
 * the cached data may not always be up to date.</p>
 */
public interface GameProfileManager extends GameProfileProvider {

    /**
     * Gets the {@link GameProfileCache} of this provider which will be
     * used to cache game profiles.
     *
     * <p>In vanilla, properties do not persist between restarts and profiles
     * will expire after a month.</p>
     *
     * @return The cache
     */
    GameProfileCache cache();

    /**
     * Gets a {@link GameProfileProvider} which bypasses the
     * {@link GameProfileCache}.
     *
     * @return The uncached game profile provider
     */
    GameProfileProvider uncached();
}
